Revision: 201031 RCL_3
authorDremov Kirill (Nokia-D-MSW/Tampere) <kirill.dremov@nokia.com>
Thu, 19 Aug 2010 11:09:10 +0300
branchRCL_3
changeset 20 1ddbe54d0645
parent 19 94cb00198351
child 21 ccb4f6b3db21
Revision: 201031 Kit: 201033
accessoryservices/accessoryserver/inc/Common/AccPolAccessoryPolicy.h
accessoryservices/accessoryserver/inc/Server/AccSrvASYProxyHandler.h
accessoryservices/accessoryserver/inc/Server/AccSrvConnectionHandler.h
accessoryservices/accessoryserver/inc/Server/AccSrvServerModel.h
accessoryservices/accessoryserver/inc/Server/AccSrvSettingsHandler.h
accessoryservices/accessoryserver/inc/Server/AccSrvSubAudioControl.h
accessoryservices/accessoryserver/src/ASYProxy/ASYProxyAsyLoader.cpp
accessoryservices/accessoryserver/src/ASYProxy/ASYProxyCommsStack.cpp
accessoryservices/accessoryserver/src/ConfigFileParser/AccConfigFileParser.cpp
accessoryservices/accessoryserver/src/Policy/AccPolAccessoryPolicy.cpp
accessoryservices/accessoryserver/src/Server/AccSrvASYProxyHandler.cpp
accessoryservices/accessoryserver/src/Server/AccSrvConnectionController.cpp
accessoryservices/accessoryserver/src/Server/AccSrvConnectionHandler.cpp
accessoryservices/accessoryserver/src/Server/AccSrvServerModel.cpp
accessoryservices/accessoryserver/src/Server/AccSrvSettingsHandler.cpp
accessoryservices/accessoryserver/src/Server/AccSrvSubAsyComms.cpp
accessoryservices/accessoryserver/src/Server/AccSrvSubAudioControl.cpp
accessoryservices/pluggeddisplay/edidparser/src/cea861edidparser.cpp
accessoryservices/pluggeddisplay/pluggeddisplayengine/src/edidhandler.cpp
accessoryservices/remotecontrolfw/server/inc/session.h
accessoryservices/remotecontrolfw/server/src/server.cpp
accessoryservices/remotecontrolfw/server/src/session.cpp
commonservices/commonengine/config/export.mk
commonservices/commonengine/makefile
devicesrv_plat/configuration_file_parser_api/inc/AccConfigFileParser.h
devicesrv_pub/common_platform_security_definitions_api/config/export.mk
devicesrv_pub/common_platform_security_definitions_api/makefile
devicesrv_pub/platform_path_definitions_api/config/export.mk
devicesrv_pub/platform_path_definitions_api/makefile
resourcemgmt/hwresourcesmgr/extendedlight/src/HWRMExtendedLightStatusObserver.cpp
resourcemgmt/hwresourcesmgr/server/inc/HWRMPluginHandler.h
resourcemgmt/hwresourcesmgr/server/src/HWRMPluginHandler.cpp
resourcemgmt/hwresourcesmgr/server/src/HWRMPowerCommonData.cpp
resourcemgmt/hwresourcesmgr/server/src/HWRMServer.cpp
sensorservices/tiltcompensationssy/src/tcstatetiltlistendata.cpp
sysstatemgmt/ssmcmdlists/data/noncriticalcmdlist_ext.rss
sysstatemgmt/ssmpolicyplugins/conf/ssmpolicyplugins.confml
sysstatemgmt/ssmpolicyplugins/conf/ssmpolicyplugins_101F8762.crml
sysstatemgmt/ssmpolicyplugins/ssmshutdownpolicy/src/ssmshutdownpolicy.cpp
sysstatemgmt/systemstatereferenceplugins/clayer/inc/starterdomaincrkeys.h
sysstatemgmt/systemstatereferenceplugins/custcmd/inc/cmddevicesecuritycheck.h
sysstatemgmt/systemstatereferenceplugins/custcmd/src/cmddevicesecuritycheck.cpp
sysstatemgmt/systemstatereferenceplugins/custcmd/src/cmdpublishstartupmode.cpp
sysstatemgmt/systemstatereferenceplugins/custcmd/src/cmdsimsecuritycheck.cpp
--- a/accessoryservices/accessoryserver/inc/Common/AccPolAccessoryPolicy.h	Thu Jul 15 20:05:35 2010 +0300
+++ b/accessoryservices/accessoryserver/inc/Common/AccPolAccessoryPolicy.h	Thu Aug 19 11:09:10 2010 +0300
@@ -231,12 +231,12 @@
         * Detect all subblock capabilities and append them to the given
         * array.
         */
-        void ParseSubblocks( const TUint64& aVal, RArray<TUint64>& aCaps );
+        void ParseSubblocksL( const TUint64& aVal, RArray<TUint64>& aCaps );
 
         /**
         * Detect all subblock names and append them to the given array.
         */
-        void ParseNames( const TUint32& aVal, RArray<TUint32>& aNames );
+        void ParseNamesL( const TUint32& aVal, RArray<TUint32>& aNames );
         
         /**
         * Find a bit number from bitmask.
--- a/accessoryservices/accessoryserver/inc/Server/AccSrvASYProxyHandler.h	Thu Jul 15 20:05:35 2010 +0300
+++ b/accessoryservices/accessoryserver/inc/Server/AccSrvASYProxyHandler.h	Thu Aug 19 11:09:10 2010 +0300
@@ -123,7 +123,7 @@
         * @return Transaction ID assigned to this operation.
         * @see RemoveTransactionID
         */
-        TInt StoreTransactionID( TProcessCmdId aCmdId,
+        TInt StoreTransactionIDL( TProcessCmdId aCmdId,
                                  TASYCommandParamRecord& aASYCommand,
                                  TPtr8* aPtrBuf );
 
--- a/accessoryservices/accessoryserver/inc/Server/AccSrvConnectionHandler.h	Thu Jul 15 20:05:35 2010 +0300
+++ b/accessoryservices/accessoryserver/inc/Server/AccSrvConnectionHandler.h	Thu Aug 19 11:09:10 2010 +0300
@@ -275,7 +275,7 @@
         * During response handling name in question can be retrieved from here
         * according to the transaction Id with FindRequestData() method.
         */
-        void StoreRequestData( TAccPolNameRecord aName, 
+        void StoreRequestDataL( TAccPolNameRecord aName, 
                                TInt aTrId, 
                                TBool aUpdateConnectionNotification );
 
--- a/accessoryservices/accessoryserver/inc/Server/AccSrvServerModel.h	Thu Jul 15 20:05:35 2010 +0300
+++ b/accessoryservices/accessoryserver/inc/Server/AccSrvServerModel.h	Thu Aug 19 11:09:10 2010 +0300
@@ -379,7 +379,7 @@
         * @param aThreadID ASYs thread ID to be stored.
         * @return void
         */
-        void AddASYThreadId( TUint aThreadID );
+        void AddASYThreadIdL( TUint aThreadID );
 
         /**
         * Creates mapping between Generic ID and ASY.
@@ -391,7 +391,7 @@
         * @param aUniqueID Unique identifier of a Generic ID.
         * @return void
         */
-        void StoreASYThreadID( TUint aThreadID, TInt aUniqueID );
+        void StoreASYThreadIDL( TUint aThreadID, TInt aUniqueID );
 
         /**
         * Removes mapping between Generic ID and ASY.
@@ -428,7 +428,7 @@
         * @return void
         * @see FindAndDeleteMsgThreadIDFilter()
         */
-        void SetMsgThreadIDFilter( TUint aThreadID, TMsgID aMsgID );
+        void SetMsgThreadIDFilterL( TUint aThreadID, TMsgID aMsgID );
 
         /**
         * Find and delete a Thread Id/message filter.
--- a/accessoryservices/accessoryserver/inc/Server/AccSrvSettingsHandler.h	Thu Jul 15 20:05:35 2010 +0300
+++ b/accessoryservices/accessoryserver/inc/Server/AccSrvSettingsHandler.h	Thu Aug 19 11:09:10 2010 +0300
@@ -233,7 +233,7 @@
         /**
         * Returns all static keys for accessory mode.
         */
-        void GetStaticKeys( const TAccMode aAccMode,
+        void GetStaticKeysL( const TAccMode aAccMode,
                    RArray< TUint32 >& aArray ) const;
 
     public:     // Data
--- a/accessoryservices/accessoryserver/src/ASYProxy/ASYProxyAsyLoader.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/accessoryservices/accessoryserver/src/ASYProxy/ASYProxyAsyLoader.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -382,7 +382,7 @@
 
         if ( found == EFalse )
             {
-            onlyServicesIndexArray.Append( i );
+            onlyServicesIndexArray.AppendL( i );
             }
         }
 
@@ -397,7 +397,7 @@
             iServiceImplInfoArray.operator[]( onlyServicesIndexArray.operator[]( k ) );
 
         iServiceImplInfoArray.Remove( onlyServicesIndexArray.operator[]( k ) );
-        iServiceImplInfoArray.Append( implementationInformation );
+        iServiceImplInfoArray.AppendL( implementationInformation );
         }
 
     // Find Service / Handler pairs
@@ -423,7 +423,7 @@
     zeroUid.iUid = ZEROHANDLERUID;
     while ( iImplUidsHandlerArray.Count() < iServiceImplInfoArray.Count() )
         {
-        iImplUidsHandlerArray.Append( zeroUid );
+        iImplUidsHandlerArray.AppendL( zeroUid );
         }
 
     User::RequestComplete( ptrStat, KErrNone );
--- a/accessoryservices/accessoryserver/src/ASYProxy/ASYProxyCommsStack.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/accessoryservices/accessoryserver/src/ASYProxy/ASYProxyCommsStack.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -121,8 +121,10 @@
         }
 
     CASYProxyTRRecord* asyProxyTRRecord = CASYProxyTRRecord::NewL( aASYProxyCommandObserver );
-    iTRRecordArray.Append( asyProxyTRRecord );
-
+    CleanupStack::PushL ( asyProxyTRRecord );
+    iTRRecordArray.AppendL( asyProxyTRRecord );
+	CleanupStack::Pop(1);
+			
     aASYProxyCommandObserver->InitializeRef( asyProxyTRRecord );
     aASYProxyCommandObserver->IssueRequestL();
 
--- a/accessoryservices/accessoryserver/src/ConfigFileParser/AccConfigFileParser.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/accessoryservices/accessoryserver/src/ConfigFileParser/AccConfigFileParser.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -50,15 +50,15 @@
 // ============================ MEMBER FUNCTIONS ===============================
 
 // -----------------------------------------------------------------------------
-// CAccConfigFileParser::ParseSubblocks
+// CAccConfigFileParser::ParseSubblocksL
 // Detecting subblocks and store them to destination array
 // (other items were commented in a header).
 // -----------------------------------------------------------------------------
 //
-void CAccConfigFileParser::ParseSubblocks( const TUint64& aVal,
+void CAccConfigFileParser::ParseSubblocksL( const TUint64& aVal,
                                            RArray<TUint64>& aCaps )
     {
-    COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseSubblocks()" );
+    COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseSubblocksL()" );
 
     TUint64 sum( 0 );
     TUint64 curVal( 1 );
@@ -72,7 +72,7 @@
         if ( ( curVal & aVal ) == curVal )
             {
             COM_TRACE_2( "[AccFW:SrvUtil] CAccConfigFileParser::(Cap) MATCH! HI:0x%x LO:0x%x", I64HIGH( curVal ), I64LOW( curVal ) );
-            aCaps.Append( curVal ); // Append to found caps array
+            aCaps.AppendL( curVal ); // Append to found caps array
             sum += curVal;
             }        
         curBit++;
@@ -80,32 +80,32 @@
         }
     while ( sum < aVal && curBit < KAccConfigMaxCapabilityGroups );
 
-    COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseSubblocks - return void" );
+    COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseSubblocksL - return void" );
     }
 
 // -----------------------------------------------------------------------------
-// CAccConfigFileParser::ParseNames
+// CAccConfigFileParser::ParseNamesL
 // Detect all subblock names and append them to the gicen array.
 // (other items were commented in a header).
 // -----------------------------------------------------------------------------
 //
-void CAccConfigFileParser::ParseNames( const TUint32& aVal,
+void CAccConfigFileParser::ParseNamesL( const TUint32& aVal,
                                        RArray<TUint32>& aNames )
     {
-    COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNames()" );
+    COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNamesL()" );
     TUint32 sum( 0 );
     TUint32 curVal( 1 );
     TInt curBit( 0 );
 
     do {
-        COM_TRACE_2( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNames Binary for this roundtrip is 0x%x, total sum is 0x%x", curVal, sum );
-        COM_TRACE_1( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNames & 0x%x", curVal & aVal );
+        COM_TRACE_2( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNamesL Binary for this roundtrip is 0x%x, total sum is 0x%x", curVal, sum );
+        COM_TRACE_1( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNamesL & 0x%x", curVal & aVal );
         // Check if this subblock is defined in SB-def block
 
         if ( ( curVal & aVal ) == curVal )
             {
             COM_TRACE_1( "[AccFW:SrvUtil] (Name) MATCH! 0x%x",curVal );
-            aNames.Append( curVal ); // Append to found caps array
+            aNames.AppendL( curVal ); // Append to found caps array
             sum += curVal;
             }
         curBit++;
@@ -113,7 +113,7 @@
         }
     while ( sum < aVal && curBit < KAccConfigMaxCapabilityGroups );
 
-    COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNames - return void" );
+    COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNamesL - return void" );
     }
 
 // -----------------------------------------------------------------------------
--- a/accessoryservices/accessoryserver/src/Policy/AccPolAccessoryPolicy.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/accessoryservices/accessoryserver/src/Policy/AccPolAccessoryPolicy.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -819,7 +819,7 @@
         TAccPolGenericIDAccessor::SetFeatureAttributeL( 
             genericID, KAccPolSBCapabilities, valU64 );
 
-        ParseSubblocks( valU64, foundCapabilityGroups );
+        ParseSubblocksL( valU64, foundCapabilityGroups );
 
         //set "values" to point to firts value
         TLex8 values;
@@ -871,7 +871,7 @@
                 TUint32 capabilityGroupValue(0);
                 lVal.Val( capabilityGroupValue, EDecimal );
 
-                ParseNames( capabilityGroupValue, foundCapability );
+                ParseNamesL( capabilityGroupValue, foundCapability );
 
                 TInt capabilityIter(0);
                 TInt foundCapabilityCount( foundCapability.Count() );
@@ -970,7 +970,7 @@
                                                                 value,
                                                               ( TAccPolValueType )type,
                                                               ( TAccPolValueLocation )location );
-                        nameValueArray.Append( nameValueRecord );
+                        nameValueArray.AppendL( nameValueRecord );
                         }
                     ++capabilityIter;
                     }
@@ -1004,14 +1004,14 @@
     }
 
 // -----------------------------------------------------------------------------
-// CAccPolAccessoryPolicy::ParseSubblocks
+// CAccPolAccessoryPolicy::ParseSubblocksL
 // Detecting subblocks and store them to destination array
 // (other items were commented in a header).
 // -----------------------------------------------------------------------------
 //
-void CAccPolAccessoryPolicy::ParseSubblocks( const TUint64& aVal, RArray<TUint64>& aCaps )
+void CAccPolAccessoryPolicy::ParseSubblocksL( const TUint64& aVal, RArray<TUint64>& aCaps )
     {
-    COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseSubblocks()" );
+    COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseSubblocksL()" );
 
     TUint64 sum( 0 );
     TUint64 curVal( 1 );
@@ -1025,7 +1025,7 @@
         if ( ( curVal & aVal ) == curVal )
             {
             COM_TRACE_2( "[AccFW:SrvUtil] CAccConfigFileParser::(Cap) MATCH! HI:0x%x LO:0x%x", I64HIGH( curVal ), I64LOW( curVal ) );
-            aCaps.Append( curVal ); // Append to found caps array
+            aCaps.AppendL( curVal ); // Append to found caps array
             sum += curVal;
             }
         curBit++;
@@ -1033,31 +1033,31 @@
         }
     while ( sum < aVal && curBit < KAccConfigMaxCapabilityGroups );
 
-    COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseSubblocks - return void" );
+    COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseSubblocksL - return void" );
     }
 
 // -----------------------------------------------------------------------------
-// CAccPolAccessoryPolicy::ParseNames
+// CAccPolAccessoryPolicy::ParseNamesL
 // Detect all subblock names and append them to the gicen array.
 // (other items were commented in a header).
 // -----------------------------------------------------------------------------
 //
-void CAccPolAccessoryPolicy::ParseNames( const TUint32& aVal, RArray<TUint32>& aNames )
+void CAccPolAccessoryPolicy::ParseNamesL( const TUint32& aVal, RArray<TUint32>& aNames )
     {
-    COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNames()" );
+    COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNamesL()" );
     TUint32 sum( 0 );
     TUint32 curVal( 1 );
     TInt curBit( 0 );
 
     do {
-        COM_TRACE_2( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNames Binary for this roundtrip is 0x%x, total sum is 0x%x", curVal, sum );
-        COM_TRACE_1( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNames & 0x%x", curVal & aVal );
+        COM_TRACE_2( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNamesL Binary for this roundtrip is 0x%x, total sum is 0x%x", curVal, sum );
+        COM_TRACE_1( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNamesL & 0x%x", curVal & aVal );
         // Check if this subblock is defined in SB-def block
 
         if ( ( curVal & aVal ) == curVal )
             {
             COM_TRACE_1( "[AccFW:SrvUtil] (Name) MATCH! 0x%x",curVal );
-            aNames.Append( curVal ); // Append to found caps array
+            aNames.AppendL( curVal ); // Append to found caps array
             sum += curVal;
             }
         curBit++;
@@ -1065,7 +1065,7 @@
         }
     while ( sum < aVal && curBit < KAccConfigMaxCapabilityGroups );
 
-    COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNames - return void" );
+    COM_TRACE_( "[AccFW:SrvUtil] CAccConfigFileParser::ParseNamesL - return void" );
     }
 
 // -----------------------------------------------------------------------------
--- a/accessoryservices/accessoryserver/src/Server/AccSrvASYProxyHandler.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/accessoryservices/accessoryserver/src/Server/AccSrvASYProxyHandler.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -127,7 +127,7 @@
         }
     else
         {
-        trID = StoreTransactionID( aCmdId, aASYCommand, aPtrBuf );
+        trID = StoreTransactionIDL( aCmdId, aASYCommand, aPtrBuf );
         }
 
     COM_TRACE_1( "[AccFW:AccServer] CAccSrvASYProxyHandler::HandleASYCommsL - return TrID=%d", trID );
@@ -135,22 +135,22 @@
     }
 
 // -----------------------------------------------------------------------------
-// CAccSrvASYProxyHandler::StoreTransactionID
+// CAccSrvASYProxyHandler::StoreTransactionIDL
 // -----------------------------------------------------------------------------
 //
-TInt CAccSrvASYProxyHandler::StoreTransactionID(
+TInt CAccSrvASYProxyHandler::StoreTransactionIDL(
     TProcessCmdId aCmdId,
     TASYCommandParamRecord& aASYCommand,
     TPtr8* aPtrBuf )
     {
-    COM_TRACE_( "[AccFW:AccServer] CAccSrvASYProxyHandler::StoreTransactionID()" );
+    COM_TRACE_( "[AccFW:AccServer] CAccSrvASYProxyHandler::StoreTransactionIDL()" );
 
     TInt trID( KErrNotFound );
     TInt count( iOngoingTransactions.Count() );
     TUint32 nameFromOngoingTransactions;
     TUint32 nameFromRequest;
 
-    COM_TRACE_1( "[AccFW:AccServer] CAccSrvASYProxyHandler::StoreTransactionID - current count = %d", count );
+    COM_TRACE_1( "[AccFW:AccServer] CAccSrvASYProxyHandler::StoreTransactionIDL - current count = %d", count );
 
     for ( TInt i( 0 ); i < count; ++i )
         {
@@ -163,7 +163,7 @@
             {
             //Same command is under processing in ASY -> use existing trid
             trID = iOngoingTransactions.operator[](i).iTransactionID;
-            COM_TRACE_1( "[AccFW:AccServer] CAccSrvASYProxyHandler::StoreTransactionID - found trid = %d", trID );
+            COM_TRACE_1( "[AccFW:AccServer] CAccSrvASYProxyHandler::StoreTransactionIDL - found trid = %d", trID );
             break;
             }
         else
@@ -180,7 +180,7 @@
         trIDRecord.iNameRecord    = aASYCommand.iNameRecord;
         trIDRecord.iCommand       = aASYCommand.iCmdValue;
         trIDRecord.iTransactionID = trID;
-        iOngoingTransactions.Append( trIDRecord );
+        iOngoingTransactions.AppendL( trIDRecord );
         
         //Complete outstanding NotifyProcessCommand()
         TRAP_IGNORE( iConnectionController->NotificationQueue().CompleteASYCmdL( 
@@ -196,7 +196,7 @@
         //This means also that ASY is not informed about this command.
         }
 
-    COM_TRACE_1( "[AccFW:AccServer] CAccSrvASYProxyHandler::StoreTransactionID - return %d", trID );
+    COM_TRACE_1( "[AccFW:AccServer] CAccSrvASYProxyHandler::StoreTransactionIDL - return %d", trID );
     return trID;
     }
 
@@ -217,7 +217,7 @@
         if ( iOngoingTransactions.operator[]( i ).iTransactionID == aTransactionID )
             {
             iOngoingTransactions.Remove( i );
-            COM_TRACE_1( "[AccFW:AccServer] CAccSrvASYProxyHandler::StoreTransactionID - removed index = %d",i );
+            COM_TRACE_1( "[AccFW:AccServer] CAccSrvASYProxyHandler::StoreTransactionIDL - removed index = %d",i );
             break;
             }
         else
--- a/accessoryservices/accessoryserver/src/Server/AccSrvConnectionController.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/accessoryservices/accessoryserver/src/Server/AccSrvConnectionController.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -277,7 +277,7 @@
 	    COM_TRACE_( "[AccFW:AccServer] CAccSrvConnectionController::HandleConnectL() New connection" );
 
 	    // Store ThreadId for ASY handling
-	    iServerModel->StoreASYThreadID( aCallerThreadID, aGenericID.UniqueID() );
+	    iServerModel->StoreASYThreadIDL( aCallerThreadID, aGenericID.UniqueID() );
 
 	    iServerModel->AddPhysicalConnectionL( aGenericID );		
 
--- a/accessoryservices/accessoryserver/src/Server/AccSrvConnectionHandler.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/accessoryservices/accessoryserver/src/Server/AccSrvConnectionHandler.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -148,7 +148,7 @@
 
 	    		//Stored request data is used when response is received from ASY
 		    	//(i.e. HandleValueMessageL)
-    			StoreRequestData( asyCommandParamRecord.iNameRecord, trId, ETrue );
+    			StoreRequestDataL( asyCommandParamRecord.iNameRecord, trId, ETrue );
 
 	    		//Store this object to queue to be able to receive response from ASY
     			iCallback->RegisterControlMessageL( ESetValue, this );
@@ -613,30 +613,30 @@
 
     //Stored request data is used when response is received from ASY
     //(i.e. HandleValueMessageL)
-    StoreRequestData( aASYCommandParam.iNameRecord, trId, EFalse );
+    StoreRequestDataL( aASYCommandParam.iNameRecord, trId, EFalse );
 
     //Store this object to queue to be able to receive response from ASY
     iCallback-> RegisterControlMessageL( EGetValue, this );
 
     }
 // -----------------------------------------------------------------------------
-// CAccSrvConnectionHandler::StoreRequestData
+// CAccSrvConnectionHandler::StoreRequestDataL
 // -----------------------------------------------------------------------------
 //
-void CAccSrvConnectionHandler::StoreRequestData( TAccPolNameRecord aName,
+void CAccSrvConnectionHandler::StoreRequestDataL( TAccPolNameRecord aName,
                                                  TInt aTrId,
                                                  TBool aUpdateConnectionNotification )
     {
-    COM_TRACE_( "[AccFW:AccServer] CAccSrvConnectionHandler::StoreRequestData()" );
+    COM_TRACE_( "[AccFW:AccServer] CAccSrvConnectionHandler::StoreRequestDataL()" );
 
     TAccSrvRequestData requestData;
     requestData.iName = aName;
     requestData.iTrId = aTrId;
     requestData.iUpdateNotification = aUpdateConnectionNotification;
 
-    iRequestDataArray.Append( requestData );
+    iRequestDataArray.AppendL( requestData );
 
-    COM_TRACE_( "[AccFW:AccServer] CAccSrvConnectionHandler::StoreRequestData - return void" );
+    COM_TRACE_( "[AccFW:AccServer] CAccSrvConnectionHandler::StoreRequestDataL - return void" );
     }
 
 // -----------------------------------------------------------------------------
--- a/accessoryservices/accessoryserver/src/Server/AccSrvSettingsHandler.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/accessoryservices/accessoryserver/src/Server/AccSrvSettingsHandler.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -453,7 +453,7 @@
         	
 	RArray< TUint32 > array;
 	CleanupClosePushL( array );
-    GetStaticKeys( aAccMode, array );
+    GetStaticKeysL( aAccMode, array );
   	TAccModeSetting setting;
     
     // get mode related static settings for client
@@ -899,45 +899,45 @@
     }
 
 // -----------------------------------------------------------------------------
-// CAccSrvSettingsHandler::GetStaticKeys
+// CAccSrvSettingsHandler::GetStaticKeysL
 //
 // (other items were commented in a header).
 // -----------------------------------------------------------------------------
 //
-void CAccSrvSettingsHandler::GetStaticKeys(
+void CAccSrvSettingsHandler::GetStaticKeysL(
                     const TAccMode aAccMode,
                     RArray< TUint32 >& aArray ) const
     {
-    COM_TRACE_1( "[AccFW:AccServer] CAccSrvSettingsHandler::GetStaticKeys(%d)", aAccMode );
+    COM_TRACE_1( "[AccFW:AccServer] CAccSrvSettingsHandler::GetStaticKeysL(%d)", aAccMode );
 
     switch( aAccMode )
         {
         case EAccModeWiredHeadset:
-            aArray.Append( KAccServerWiredHSLights );
+            aArray.AppendL( KAccServerWiredHSLights );
             break;
         case EAccModeWirelessHeadset:
-            aArray.Append( KAccServerWirelessHSLights );
+            aArray.AppendL( KAccServerWirelessHSLights );
             break;
         case EAccModeWiredCarKit:
-            aArray.Append( KAccServerWiredCarKitLights );
+            aArray.AppendL( KAccServerWiredCarKitLights );
             break;
         case EAccModeWirelessCarKit:
-            aArray.Append( KAccServerWirelessCarKitLights );
+            aArray.AppendL( KAccServerWirelessCarKitLights );
             break;
         case EAccModeTextDevice:
-            aArray.Append( KAccServerTextDeviceLights );
+            aArray.AppendL( KAccServerTextDeviceLights );
             break;
         case EAccModeLoopset:
-            aArray.Append( KAccServerLoopsetLights );
+            aArray.AppendL( KAccServerLoopsetLights );
             break;
         case EAccModeMusicStand:
-            aArray.Append( KAccServerMusicStandLights );
+            aArray.AppendL( KAccServerMusicStandLights );
             break;
         default:  // mode is not supported
             break;
         }
 
-    COM_TRACE_( "[AccFW:AccServer] CAccSrvSettingsHandler::GetStaticKeys() returns" );
+    COM_TRACE_( "[AccFW:AccServer] CAccSrvSettingsHandler::GetStaticKeysL() returns" );
     }
 
 // ========================== OTHER EXPORTED FUNCTIONS =========================
--- a/accessoryservices/accessoryserver/src/Server/AccSrvSubAsyComms.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/accessoryservices/accessoryserver/src/Server/AccSrvSubAsyComms.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -82,7 +82,7 @@
     COM_TRACE_( "[AccFW:AccServer] CAccSrvSubAsyComms::ConstructL()" );
 
     iInitCommandTimer = CAccSrvProcessCommandTimer::NewL( this, KInitCmdTimeOut );
-    iServerModel->AddASYThreadId( iASYThreadID );
+    iServerModel->AddASYThreadIdL( iASYThreadID );
 
     COM_TRACE_( "[AccFW:AccServer] CAccSrvSubAsyComms::ConstructL - return void" );
     }
--- a/accessoryservices/pluggeddisplay/edidparser/src/cea861edidparser.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/accessoryservices/pluggeddisplay/edidparser/src/cea861edidparser.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -600,7 +600,8 @@
         
     TCEA861TEdidDescriptorBlockList* lastnode = iParsedInfo->iDescriptorBlocks;
 
-    for( TInt index = aIndex; index < KEdidParserSizeOfEdidBlock; index++ )
+    TInt index = aIndex;
+    while( index < KEdidParserSizeOfEdidBlock )
         {
         // Offset. If this is a newer version of CEA-861,
         // then this is skipped (we are already past the offset)
@@ -635,6 +636,7 @@
         else
             {
             // this is only padding, no need to do anything
+            index++;
             }
 
         // after the descriptors there is padding to fill Extension block to 128 bytes.
--- a/accessoryservices/pluggeddisplay/pluggeddisplayengine/src/edidhandler.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/accessoryservices/pluggeddisplay/pluggeddisplayengine/src/edidhandler.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -542,7 +542,6 @@
 					INFO_1( "Updating the Rawdata for the Block %d...", iCurrentBlock );
 					iEdidParserPtr->UpdateRawDataL(dataBlockDes);
 					
-					iCurrentBlock++;
 					if( inbrOfExtensions >= 2 )
 						{
  						inbrOfExtensions = inbrOfExtensions - 2;
@@ -555,6 +554,7 @@
 
 				if( inbrOfExtensions )
 					{
+					iCurrentBlock++;
 					iRetryCounter = KErrNone;
 					
 					if( ReadEDIDDataL() != KErrNone )
@@ -587,12 +587,11 @@
 								}
  							}
 						}
+					TRACE_EDID_DATA( *iEdidParserPtr );
+					
+					iFSM.Input( EPDEIfEDIDHandler, EPDEIfEDIDHandlerEventEdidDataFetched );
+					iRetryCounter = KErrNone;
 					}
-
-				TRACE_EDID_DATA( *iEdidParserPtr );
-				
-				iFSM.Input( EPDEIfEDIDHandler, EPDEIfEDIDHandlerEventEdidDataFetched );
-				iRetryCounter = KErrNone;
 				}
             else
                 {
@@ -1557,6 +1556,30 @@
 		    else // It is DVI connector
 		    {
 				TInt modecount = aHdmiConfigs.Count();
+
+				if( !modecount )
+					{
+					THdmiDviTimings timings;
+					
+					INFO( "==No EDID available from the Sink. Setting DMT 4" );
+					// No EDID data available from the sink
+					// Default VGA resolution should be selected
+					const TTimingItem* item = TimingByIndex( KDefaultDMTModeIndex, ETimingModeDMT );
+					if( item )
+						{
+						Mem::FillZ( ( TAny* )&timings, sizeof( timings ) );
+						FillHdmiDviTimings( *item, timings );
+						timings.iTvPhysicalImageAspectRatioNumerator = 4;
+						timings.iTvPhysicalImageAspectRatioDenominator = 3;
+						retVal = aHdmiConfigs.Append( timings );
+						ERROR_1( retVal, "Failed to append DMT timing: %S in array", item->iTimingName );
+						if( retVal == KErrNone )
+							{
+							modecount = 1;
+							ceaMode = EFalse;
+							}
+						}
+					}
 				
 				while( modecount-- )
 				  {
--- a/accessoryservices/remotecontrolfw/server/inc/session.h	Thu Jul 15 20:05:35 2010 +0300
+++ b/accessoryservices/remotecontrolfw/server/inc/session.h	Thu Aug 19 11:09:10 2010 +0300
@@ -1,4 +1,4 @@
-// Copyright (c) 2004-2009 Nokia Corporation and/or its subsidiary(-ies).
+// Copyright (c) 2004-2010 Nokia Corporation and/or its subsidiary(-ies).
 // All rights reserved.
 // This component and the accompanying materials are made available
 // under the terms of "Eclipse Public License v1.0"
@@ -142,6 +142,8 @@
 	TInt SupportedBulkInterfaces(RArray<TUid>& aUids);
 	TInt SupportedOperations(TUid aInterfaceUid, RArray<TUint>& aOperations);
 
+	TBool ClientAvailable() const;
+
 	/**
 	Panics the client's current Send message with the given code.
 	*/
--- a/accessoryservices/remotecontrolfw/server/src/server.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/accessoryservices/remotecontrolfw/server/src/server.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -1,4 +1,4 @@
-// Copyright (c) 2004-2009 Nokia Corporation and/or its subsidiary(-ies).
+// Copyright (c) 2004-2010 Nokia Corporation and/or its subsidiary(-ies).
 // All rights reserved.
 // This component and the accompanying materials are made available
 // under the terms of "Eclipse Public License v1.0"
@@ -1740,28 +1740,36 @@
 	LOGINCOMINGDELIVERED;
 	TInt err = KErrNone;
 
-	// First off check if the client supports this
-	if(!aSess.SupportedMessage(aMsg))
-        {
-        err = KErrArgument;
-        
-        // 'Take ownership' of it by destroying it- it's finished with.
-        delete &aMsg;
-        }
-	else if ( aSess.CurrentReceiveMessage().Handle() )
+	if ( aSess.ClientAvailable() )
 		{
-		// If the client can take the message now put it on the right queue.
+		// First off check if the client supports this
+		if(!aSess.SupportedMessage(aMsg))
+			{
+			err = KErrArgument;
+
+			// 'Take ownership' of it by destroying it- it's finished with.
+			delete &aMsg;
+			}
+		else if ( aSess.CurrentReceiveMessage().Handle() )
+			{
+			// If the client can take the message now put it on the right queue.
 
-		err = aSess.WriteMessageToClient (aMsg);
-		// If the message was a command, and it was delivered with no error, 
-		// then put it in the 'incoming delivered' log. Otherwise, delete it 
-		// because it's finished with.
-		if ((aMsg.MsgType() == ERemConCommand) || (aMsg.MsgType() == ERemConNotifyCommand))
-			{
-			if (err == KErrNone )
+			err = aSess.WriteMessageToClient (aMsg);
+			// If the message was a command, and it was delivered with no error,
+			// then put it in the 'incoming delivered' log. Otherwise, delete it
+			// because it's finished with.
+			if ((aMsg.MsgType() == ERemConCommand) || (aMsg.MsgType() == ERemConNotifyCommand))
 				{
-				// We'll need to remember it for the response coming back.
-				IncomingDelivered().Append(aMsg); 
+				if (err == KErrNone )
+					{
+					// We'll need to remember it for the response coming back.
+					IncomingDelivered().Append(aMsg);
+					}
+				else
+					{
+					// 'Take ownership' of it by destroying it- it's finished with.
+					delete &aMsg;
+					}
 				}
 			else
 				{
@@ -1771,12 +1779,19 @@
 			}
 		else
 			{
-			// 'Take ownership' of it by destroying it- it's finished with.			
-			delete &aMsg;
+			IncomingPendingDelivery().Append(aMsg);
 			}
 		}
 	else
 		{
+		// The client has not yet registered the interfaces they're interested
+		// in, so put the message on the incoming pending delivery queue until
+		// they do.
+		// Return KErrNone to avoid sending a reject. We're assuming that the
+		// client will eventually successfully receive the message, as we
+		// don't have a better basis on which to operate. This is identical to
+		// the case where a client doesn't have an outstanding receive request
+		// at this time.
 		IncomingPendingDelivery().Append(aMsg);
 		}
 	
--- a/accessoryservices/remotecontrolfw/server/src/session.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/accessoryservices/remotecontrolfw/server/src/session.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -1,4 +1,4 @@
-// Copyright (c) 2004-2009 Nokia Corporation and/or its subsidiary(-ies).
+// Copyright (c) 2004-2010 Nokia Corporation and/or its subsidiary(-ies).
 // All rights reserved.
 // This component and the accompanying materials are made available
 // under the terms of "Eclipse Public License v1.0"
@@ -1794,6 +1794,13 @@
 	return err;
 	}
 
+TBool CRemConSession::ClientAvailable() const
+	{
+	// Client is available as soon as it has registered the APIs
+	// it is interested in.
+	return !!iInterestedAPIs;
+	}
+
 CRemConInterfaceDetails* CRemConSession::FindInterfaceByUid(TUid aUid) const
 	{
 	LOG_FUNC
--- a/commonservices/commonengine/config/export.mk	Thu Jul 15 20:05:35 2010 +0300
+++ b/commonservices/commonengine/config/export.mk	Thu Aug 19 11:09:10 2010 +0300
@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies).
+# Copyright (c) 2009-2010 Nokia Corporation and/or its subsidiary(-ies).
 # All rights reserved.
 # This component and the accompanying materials are made available
 # under the terms of "Eclipse Public License v1.0"
@@ -17,11 +17,11 @@
 
 # commonengine's actual configuration export makefile
 
-MAKEFILE = 	/sf/os/devicesrv/commonservices/commonengine/config/export.mk
+MAKEFILE = 	$(EPOCROOT)/sf/os/devicesrv/commonservices/commonengine/config/export.mk
 $(call push,MAKEFILE_STACK,$(MAKEFILE))
 
-CONFFILES =		$(MAKEFILEDIR)../conf/commonengine.confml              	/epoc32/rom/config/confml_data/s60/ \
-							$(MAKEFILEDIR)../conf/commonengine_1020503B.crml 	     	/epoc32/rom/config/confml_data/s60/
+CONFFILES =		$(MAKEFILEDIR)../conf/commonengine.confml              	$(EPOCROOT)/epoc32/rom/config/confml_data/s60/ \
+							$(MAKEFILEDIR)../conf/commonengine_1020503B.crml 	     	$(EPOCROOT)/epoc32/rom/config/confml_data/s60/
 		
 commonengine_config					:: commonengine_config-conf
 commonengine_config-conf 		::
--- a/commonservices/commonengine/makefile	Thu Jul 15 20:05:35 2010 +0300
+++ b/commonservices/commonengine/makefile	Thu Aug 19 11:09:10 2010 +0300
@@ -2,7 +2,7 @@
 
 #Define this platform as default if nothing is defined
 
-MAKEFILE = /sf/os/devicesrv/commonservices/commonengine/makefile
+MAKEFILE = $(EPOCROOT)/sf/os/devicesrv/commonservices/commonengine/makefile
 
 commonengine_all    :: commonengine_config
 
--- a/devicesrv_plat/configuration_file_parser_api/inc/AccConfigFileParser.h	Thu Jul 15 20:05:35 2010 +0300
+++ b/devicesrv_plat/configuration_file_parser_api/inc/AccConfigFileParser.h	Thu Aug 19 11:09:10 2010 +0300
@@ -143,12 +143,12 @@
         * Detect all subblock capabilities and append them to the given
         * array.
         */
-        void ParseSubblocks( const TUint64& aVal, RArray<TUint64>& aCaps );
+        void ParseSubblocksL( const TUint64& aVal, RArray<TUint64>& aCaps );
 
         /**
         * Detect all subblock names and append them to the given array.
         */
-        void ParseNames( const TUint32& aVal, RArray<TUint32>& aNames );
+        void ParseNamesL( const TUint32& aVal, RArray<TUint32>& aNames );
         
         /**
         * Find a bit number from bitmask.
--- a/devicesrv_pub/common_platform_security_definitions_api/config/export.mk	Thu Jul 15 20:05:35 2010 +0300
+++ b/devicesrv_pub/common_platform_security_definitions_api/config/export.mk	Thu Aug 19 11:09:10 2010 +0300
@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies). 
+# Copyright (c) 2009-2010 Nokia Corporation and/or its subsidiary(-ies). 
 # All rights reserved.
 # This component and the accompanying materials are made available
 # under the terms of "Eclipse Public License v1.0"
@@ -18,14 +18,14 @@
 
 # common_platform_security_definitions_api's actual configuration export makefile
 
-MAKEFILE = 	/sf/os/devicesrv/devicesrv_pub/common_platform_security_definitions_api/config/export.mk
+MAKEFILE = 	$(EPOCROOT)/sf/os/devicesrv/devicesrv_pub/common_platform_security_definitions_api/config/export.mk
 $(call push,MAKEFILE_STACK,$(MAKEFILE))
 
-INCFILES =		$(MAKEFILEDIR)../inc/data_caging_path_literals.hrh    /epoc32/include/ \
-							$(MAKEFILEDIR)../inc/data_caging_paths_for_iby.hrh    /epoc32/include/ \
-							$(MAKEFILEDIR)../inc/data_caging_paths.hrh            /epoc32/include/ \
-							$(MAKEFILEDIR)../inc/data_caging_paths_strings.hrh    /epoc32/include/ \
-							$(MAKEFILEDIR)../inc/data_caged_locations.mk          /epoc32/include/
+INCFILES =		$(MAKEFILEDIR)../inc/data_caging_path_literals.hrh    $(EPOCROOT)/epoc32/include/ \
+							$(MAKEFILEDIR)../inc/data_caging_paths_for_iby.hrh    $(EPOCROOT)/epoc32/include/ \
+							$(MAKEFILEDIR)../inc/data_caging_paths.hrh            $(EPOCROOT)/epoc32/include/ \
+							$(MAKEFILEDIR)../inc/data_caging_paths_strings.hrh    $(EPOCROOT)/epoc32/include/ \
+							$(MAKEFILEDIR)../inc/data_caged_locations.mk          $(EPOCROOT)/epoc32/include/
 
 
 common_platform_security_config				:: common_platform_security_config-inc
--- a/devicesrv_pub/common_platform_security_definitions_api/makefile	Thu Jul 15 20:05:35 2010 +0300
+++ b/devicesrv_pub/common_platform_security_definitions_api/makefile	Thu Aug 19 11:09:10 2010 +0300
@@ -2,7 +2,7 @@
 
 #Define this platform as default if nothing is defined
 
-MAKEFILE = /sf/os/devicesrv/devicesrv_pub/common_platform_security_definitions_api/makefile
+MAKEFILE = $(EPOCROOT)/sf/os/devicesrv/devicesrv_pub/common_platform_security_definitions_api/makefile
 
 common_platform_security_all    	:: common_platform_security_config
 
--- a/devicesrv_pub/platform_path_definitions_api/config/export.mk	Thu Jul 15 20:05:35 2010 +0300
+++ b/devicesrv_pub/platform_path_definitions_api/config/export.mk	Thu Aug 19 11:09:10 2010 +0300
@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2009 Nokia Corporation and/or its subsidiary(-ies). 
+# Copyright (c) 2009-2010 Nokia Corporation and/or its subsidiary(-ies). 
 # All rights reserved.
 # This component and the accompanying materials are made available
 # under the terms of "Eclipse Public License v1.0"
@@ -18,12 +18,12 @@
 
 # platform_path_definitions_api's actual configuration export makefile
 
-MAKEFILE = 	/sf/os/devicesrv/devicesrv_pub/platform_path_definitions_api/config/export.mk
+MAKEFILE = 	$(EPOCROOT)/sf/os/devicesrv/devicesrv_pub/platform_path_definitions_api/config/export.mk
 $(call push,MAKEFILE_STACK,$(MAKEFILE))
 
-INCFILES =		$(MAKEFILEDIR)../inc/platform_paths.hrh               /epoc32/include/ \
-							$(MAKEFILEDIR)../inc/non_foundation_paths.hrh         /epoc32/include/ \
-							$(MAKEFILEDIR)../inc/iconlocations.hrh                /epoc32/include/
+INCFILES =		$(MAKEFILEDIR)../inc/platform_paths.hrh               $(EPOCROOT)/epoc32/include/ \
+							$(MAKEFILEDIR)../inc/non_foundation_paths.hrh         $(EPOCROOT)/epoc32/include/ \
+							$(MAKEFILEDIR)../inc/iconlocations.hrh                $(EPOCROOT)/epoc32/include/
 		
 platform_path_config				:: platform_path_config-inc
 platform_path_config-inc 		::
--- a/devicesrv_pub/platform_path_definitions_api/makefile	Thu Jul 15 20:05:35 2010 +0300
+++ b/devicesrv_pub/platform_path_definitions_api/makefile	Thu Aug 19 11:09:10 2010 +0300
@@ -2,7 +2,7 @@
 
 #Define this platform as default if nothing is defined
 
-MAKEFILE = /sf/os/devicesrv/devicesrv_pub/platform_path_definitions_api/makefile
+MAKEFILE = $(EPOCROOT)/sf/os/devicesrv/devicesrv_pub/platform_path_definitions_api/makefile
 
 platform_path_all    	:: platform_path_config
 
--- a/resourcemgmt/hwresourcesmgr/extendedlight/src/HWRMExtendedLightStatusObserver.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/resourcemgmt/hwresourcesmgr/extendedlight/src/HWRMExtendedLightStatusObserver.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -81,7 +81,10 @@
 
     // Cancel property separately, as the following Cancel() call doesn't seem to 
     // cause DoCancel to fire.
-    iProperty.Cancel();
+    if( iProperty.Handle() )
+      {
+      iProperty.Cancel();
+      }
     
     Cancel();
     
--- a/resourcemgmt/hwresourcesmgr/server/inc/HWRMPluginHandler.h	Thu Jul 15 20:05:35 2010 +0300
+++ b/resourcemgmt/hwresourcesmgr/server/inc/HWRMPluginHandler.h	Thu Aug 19 11:09:10 2010 +0300
@@ -148,7 +148,7 @@
 		*
 		* @param aCallback  The indication handler to be registered
 		*/
-        void RegisterForIndications(MHWRMIndicationHandler* aCallback);
+        void RegisterForIndicationsL(MHWRMIndicationHandler* aCallback);
         
         /**
 		* Deregisters handlers for receiving HWRM plug-in indications
--- a/resourcemgmt/hwresourcesmgr/server/src/HWRMPluginHandler.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/resourcemgmt/hwresourcesmgr/server/src/HWRMPluginHandler.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -328,11 +328,11 @@
 // Registers a handler for receiving HWRM plug-in indications
 // -----------------------------------------------------------------------------
 //
-void CHWRMPluginHandler::RegisterForIndications(MHWRMIndicationHandler* aCallback)
+void CHWRMPluginHandler::RegisterForIndicationsL(MHWRMIndicationHandler* aCallback)
 	{
     COMPONENT_TRACE2( _L( "HWRM Server - CHWRMPluginHandler::RegisterForIndications(), Count() = %d" ), iIndicationCallbacks.Count() );
 
-	iIndicationCallbacks.Append(aCallback);
+	iIndicationCallbacks.AppendL(aCallback);
 	}
 
 // -----------------------------------------------------------------------------
--- a/resourcemgmt/hwresourcesmgr/server/src/HWRMPowerCommonData.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/resourcemgmt/hwresourcesmgr/server/src/HWRMPowerCommonData.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -113,7 +113,7 @@
     COMPONENT_TRACE2(_L( "HWRM Server - CHWRMPowerCommonData::ConstructL - iMaximumReportingPeriod: %d" ), iMaximumReportingPeriod );
 
     // Register for indications from HWRM plugin.
-    aPluginHandler->RegisterForIndications(this);
+    aPluginHandler->RegisterForIndicationsL(this);
     
     iPowerService = CHWRMPowerService::NewL(aPluginHandler, *this);
 
--- a/resourcemgmt/hwresourcesmgr/server/src/HWRMServer.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/resourcemgmt/hwresourcesmgr/server/src/HWRMServer.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -737,12 +737,12 @@
             iFmTxCommonData = NULL;
 			iFmTxCommonData = CHWRMFmTxCommonData::NewL();		
 			
-			iFmTxPluginHandler->RegisterForIndications(iFmTxCommonData);
+			iFmTxPluginHandler->RegisterForIndicationsL(iFmTxCommonData);
 			
 			iFmTxStateUtility = CHWRMFmTxStateUtility::NewL(iFmTxPluginHandler, 
 			         iFmTxWatcherPluginHandler, iFmTxReservationHandler, iFmTxCommonData);
 
-			iFmTxWatcherPluginHandler->RegisterForIndications(iFmTxStateUtility);
+			iFmTxWatcherPluginHandler->RegisterForIndicationsL(iFmTxStateUtility);
             }
         else
             {
--- a/sensorservices/tiltcompensationssy/src/tcstatetiltlistendata.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/sensorservices/tiltcompensationssy/src/tcstatetiltlistendata.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -471,6 +471,11 @@
         // Reset state
         ResetState( ETrue );
         }
+    else
+    	{
+    	if( iTimerToSend )
+    		iTimerToSend->Start();
+    	}
     }
 
 // ----------------------------------------------------------------------------------
--- a/sysstatemgmt/ssmcmdlists/data/noncriticalcmdlist_ext.rss	Thu Jul 15 20:05:35 2010 +0300
+++ b/sysstatemgmt/ssmcmdlists/data/noncriticalcmdlist_ext.rss	Thu Aug 19 11:09:10 2010 +0300
@@ -154,7 +154,7 @@
     priority = 0xFFA7;
     name = "z:\\sys\\bin\\lockapp.exe";
     execution_behaviour = ESsmWaitForSignal;
-    timeout = 10000;
+    timeout = 100000;		//  FCOA-87UBXX
     background = 1; // To background
     monitor_info = r_mon_3_restarts_ignore;
     }
Binary file sysstatemgmt/ssmpolicyplugins/conf/ssmpolicyplugins.confml has changed
Binary file sysstatemgmt/ssmpolicyplugins/conf/ssmpolicyplugins_101F8762.crml has changed
--- a/sysstatemgmt/ssmpolicyplugins/ssmshutdownpolicy/src/ssmshutdownpolicy.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/sysstatemgmt/ssmpolicyplugins/ssmshutdownpolicy/src/ssmshutdownpolicy.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -217,6 +217,16 @@
     TInt errorCode = repository->Set( KStartupReason, aReasonCode );
     ERROR( errorCode, "Failed to set KStartupReason CenRep key" );
 
+	// In case of disk full, we will not try to set the device lock query status cenrep key here.
+	// Rather it is set after disk space is recovered.
+	if ((EUnknownReset !=  aReasonCode) && (KErrDiskFull != errorCode))
+		{
+		// Set the lock code query success as EStartupDevLockNotSucess in case the shutdown is not due to the the unknown reset.  
+		// This is because if the device crashes before resetting the key during boot time.
+		errorCode = repository->Set(KStartupDevLockStatus, EStartupDevLockNotSucess);
+		INFO_1("Setting KStartupDevLockStatus CenRep key with EStartupDevLockNotSucess completed with %d", errorCode);
+		}
+
 	if( KErrDiskFull == errorCode )
 		{
 		//Need not to put on CleanupStack, it's not calling any leaving function and
@@ -228,6 +238,14 @@
 			{
 			errorCode = repository->Set( KStartupReason, aReasonCode );
 			ERROR( errorCode, "Failed to set KStartupReason CenRep key after freeing the memory" );
+
+			if (EUnknownReset !=  aReasonCode)
+				{
+				// Set the lock code query success as EStartupDevLockNotSucess in case the shutdown is not due to the the unknown reset.  
+				// This is because if the device crashes before resetting the key during boot time.
+				errorCode = repository->Set(KStartupDevLockStatus, EStartupDevLockNotSucess);
+				ERROR( errorCode, "Failed to set KStartupDevLockStatus CenRep key after freeing the memory" );
+				}
 			}
 		CSsmUiSpecific::Release();
 		}
--- a/sysstatemgmt/systemstatereferenceplugins/clayer/inc/starterdomaincrkeys.h	Thu Jul 15 20:05:35 2010 +0300
+++ b/sysstatemgmt/systemstatereferenceplugins/clayer/inc/starterdomaincrkeys.h	Thu Aug 19 11:09:10 2010 +0300
@@ -54,6 +54,16 @@
     EStartupNotFirstBoot
     };
 
+/**
+* Used by Starter to store the device lock status
+*/
+const TUint32 KStartupDevLockStatus = 0x00000004;
+enum TStartupDevLockSuccess
+    {
+    EStartupDevLockNotSucess = 100,
+    EStartupDevLockSucess
+    };
+
 #endif // STARTERDOMAINCRKEYS_H
 
 // End of File
--- a/sysstatemgmt/systemstatereferenceplugins/custcmd/inc/cmddevicesecuritycheck.h	Thu Jul 15 20:05:35 2010 +0300
+++ b/sysstatemgmt/systemstatereferenceplugins/custcmd/inc/cmddevicesecuritycheck.h	Thu Aug 19 11:09:10 2010 +0300
@@ -33,6 +33,8 @@
 #include <etel.h> 
 #include <etelmm.h>
 
+class CRepository;
+
 NONSHARABLE_CLASS (CCustomCmdDeviceSecurityCheck) : public CActive , public MSsmCustomCommand
 	{
 public:
@@ -94,6 +96,7 @@
     HBufC* iTsyModuleName;
 	TRequestStatus* iExecuteRequest;
 	CSsmSecurityCheckNotifier* iSsmSecurityCheckNotifier;
+	CRepository* iStartupRepository;
 
 #ifdef TEST_CUSTCMD_MACRO
 	friend class CCustomCmdTestDeviceSecurityCheck;
--- a/sysstatemgmt/systemstatereferenceplugins/custcmd/src/cmddevicesecuritycheck.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/sysstatemgmt/systemstatereferenceplugins/custcmd/src/cmddevicesecuritycheck.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -28,6 +28,11 @@
 #include "ssmuiproviderdll.h"
 #include "ssmrefcustomcmdcommon.h"
 #include "ssmdebug.h"
+#include "starterdomaincrkeys.h"
+#include "startupdomainpskeys.h"
+
+#include <centralrepository.h>
+
 
 CCustomCmdDeviceSecurityCheck* CCustomCmdDeviceSecurityCheck::NewL()
 	{
@@ -69,6 +74,8 @@
     	User::Leave(errorCode);	
     	}
 
+	iStartupRepository = CRepository::NewL(KCRUidStartup);
+
 	//Add active object to active scheduler
 	CActiveScheduler::Add(this);
 	}
@@ -92,6 +99,7 @@
         iServer.Close();
         }
     delete iTsyModuleName;
+	delete iStartupRepository;
 	}
 
 TInt CCustomCmdDeviceSecurityCheck::Initialize(CSsmCustomCommandEnv* /*aCmdEnv*/)
@@ -113,7 +121,8 @@
 	//Set the user request to pending
 	aStatus = KRequestPending;
 	iExecuteRequest = &aStatus;
-
+	
+	TInt errorCode = KErrNone;
 #ifdef __WINS__
 #ifdef TEST_CUSTCMD_MACRO
 	TRequestStatus* status = &iStatus;
@@ -122,19 +131,35 @@
 #else
     // The device lock status can not be read in the emulator.
     // Just pretend the lock is not enabled.
-	TInt errorCode = RProperty::Set(CSsmUiSpecific::StarterPSUid(), KStarterSecurityPhase, EStarterSecurityPhaseSimOk);
+	errorCode = RProperty::Set(CSsmUiSpecific::StarterPSUid(), KStarterSecurityPhase, EStarterSecurityPhaseSimOk);
     CompleteClientRequest(errorCode);
 #endif //TEST_CUSTCMD_MACRO
 
 #else
-    if (CSsmUiSpecific::IsNormalBoot() || CSsmUiSpecific::IsSimChangedReset())
+
+	TInt val(EStartupDevLockNotSucess);
+
+	errorCode = iStartupRepository->Get(KStartupDevLockStatus, val);
+	DEBUGPRINT3A("Getting KStartupDevLockStatus : %d completed with %d", val, errorCode);
+
+	TInt startupReason = 0;
+	if (EStartupDevLockNotSucess != val)
+		{
+		errorCode = iStartupRepository->Set(KStartupDevLockStatus, EStartupDevLockNotSucess);
+		DEBUGPRINT2A("Setting KStartupDevLockStatus to EStartupDevLockNotSucess completed with %d", errorCode);
+		}
+
+	errorCode = RProperty::Get(CSsmUiSpecific::StartupPSUid(), KPSStartupReason, startupReason);
+	DEBUGPRINT3A("Getting KPSStartupReason : %d completed with : %d", startupReason, errorCode);
+	
+	if (CSsmUiSpecific::IsNormalBoot() || CSsmUiSpecific::IsSimChangedReset() || (EStartupDevLockNotSucess ==  val && EUnknownReset == startupReason))
         {
         iPhone.GetLockInfo( iStatus, RMobilePhone::ELockPhoneDevice, iLockInfoPckg );
         SetActive();
         }
     else
         {
-        TInt errorCode = RProperty::Set(
+		errorCode = RProperty::Set(
         		CSsmUiSpecific::StarterPSUid(), KStarterSecurityPhase, EStarterSecurityPhaseSecOk );
         CompleteClientRequest( errorCode );
         }
@@ -285,10 +310,14 @@
 
 void CCustomCmdDeviceSecurityCheck::CompleteClientRequest(TInt aReason)
 	{
+	DEBUGPRINT2A("Device Security Check completed with %d", aReason);
+
+	TInt err = iStartupRepository->Set(KStartupDevLockStatus, (aReason == KErrNone ? EStartupDevLockSucess : EStartupDevLockNotSucess));
+    DEBUGPRINT2A("Setting KStartupDevLockStatus completed with error %d", err);
 	//Complete client request with reason code
 	if (iExecuteRequest)
         {
-    	TInt errorCode = RProperty::Set(CSsmUiSpecific::StarterPSUid(), KStarterSecurityPhase, 
+    	err = RProperty::Set(CSsmUiSpecific::StarterPSUid(), KStarterSecurityPhase, 
     			aReason == KErrNone ? EStarterSecurityPhaseSecOk : EStarterSecurityPhaseSecNok );
         User::RequestComplete(iExecuteRequest, aReason);
         }
--- a/sysstatemgmt/systemstatereferenceplugins/custcmd/src/cmdpublishstartupmode.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/sysstatemgmt/systemstatereferenceplugins/custcmd/src/cmdpublishstartupmode.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -1,4 +1,4 @@
-// Copyright (c) 2008-2009 Nokia Corporation and/or its subsidiary(-ies).
+// Copyright (c) 2008-2010 Nokia Corporation and/or its subsidiary(-ies).
 // All rights reserved.
 // This component and the accompanying materials are made available
 // under the terms of "Eclipse Public License v1.0"
@@ -150,6 +150,12 @@
                 DEBUGPRINT1A("Hidden reset detected");
                 startupReason = EUnknownReset;
                 }
+			else
+				{
+				err = iRepository->Set(KStartupDevLockStatus, EStartupDevLockNotSucess);
+				DEBUGPRINT1A("Normal Device Startup");
+				DEBUGPRINT2A("Setting KStartupDevLockStatus to EStartupDevLockNotSucess completed with error %d", err);
+				}
             
             // Publish startup reason
             err = RProperty::Set(CSsmUiSpecific::StartupPSUid(), KPSStartupReason, startupReason);
--- a/sysstatemgmt/systemstatereferenceplugins/custcmd/src/cmdsimsecuritycheck.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/sysstatemgmt/systemstatereferenceplugins/custcmd/src/cmdsimsecuritycheck.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -155,6 +155,8 @@
 	__ASSERT_ALWAYS(!IsActive(), PanicNow(KPanicCustomCmdSimSecurityCheck, EInternalStateError));
 	__ASSERT_ALWAYS(!iStateChangePending, PanicNow(KPanicCustomCmdSimSecurityCheck, EInternalStateError));
 
+	DEBUGPRINT2A("CCustomCmdSimSecurityCheck StartStateChange with State - %d ", aState);
+
 	iSubState = ESecuritySubStateNone;
 	iStateChangePending = ETrue;
 	iNoteType = aNoteType;
@@ -262,6 +264,8 @@
 
 	TInt errorCode = KErrNone;
     //Handle the state transition
+	
+	DEBUGPRINT2A("CCustomCmdSimSecurityCheck SecurityCheckL with State - %d ", iState);
     switch (iState)
         {
         case StartupAdaptation::ESIMPresent:
@@ -332,6 +336,7 @@
 
 void CCustomCmdSimSecurityCheck::DoSecurityCheck()
     {
+	DEBUGPRINT2A("CCustomCmdSimSecurityCheck DoSecurityCheck with State - %d ", iState);
     //Handle pending state transition
     switch (iState)
         {
--- a/accessoryservices/accessoryserver/inc/Server/AccSrvSubAudioControl.h	Thu Jul 15 20:05:35 2010 +0300
+++ b/accessoryservices/accessoryserver/inc/Server/AccSrvSubAudioControl.h	Thu Aug 19 11:09:10 2010 +0300
@@ -112,24 +112,24 @@
     private: // New functions
 
         /**
         * Handles NotifyAccessoryAudioLinkOpened() client request.
         * If leave occurs, the client request is completed with that error code.
         *
         * @since S60 3.1
         * @param aMessage Client request.
         * @return void
         */
-        void NotifyAccessoryAudioLinkOpened( const RMessage2& aMessage );
+        void NotifyAccessoryAudioLinkOpenedL( const RMessage2& aMessage );
 
         /**
         * Handles NotifyAccessoryAudioLinkClosed() client request.
         * If leave occurs, the client request is completed with that error code.
         *
         * @since S60 3.1
         * @param aMessage Client request.
         * @return void
         */
-        void NotifyAccessoryAudioLinkClosed( const RMessage2& aMessage );
+        void NotifyAccessoryAudioLinkClosedL( const RMessage2& aMessage );
 
         /**
         * Handles AccessoryAudioLinkOpen() client request.
@@ -182,7 +182,7 @@
         void CancelAccessoryAudioLinkClose( const RMessage2& aMessage );
 
         /**
         * Handles NotifyAccessoryAudioLinkOpened() client request.
         * If leave occurs, the client request is completed with that error code.
         *
         * @since S60 3.1
@@ -192,7 +192,7 @@
         void CancelNotifyAccessoryAudioLinkOpened( const RMessage2& aMessage );
 
         /**
         * Handles NotifyAccessoryAudioLinkClosed() client request.
         * If leave occurs, the client request is completed with that error code.
         *
         * @since S60 3.1
@@ -213,10 +213,10 @@
         //Stored AccessoryAudioLinkClose() client request for later completion.
         RMessage2 iAccessoryAudioLinkCloseMsg;
 
         //Stored NotifyAccessoryAudioLinkOpened() client request for later completion.
         RMessage2 iNotifyAccessoryAudioLinkOpenedMsg;
 
         //Stored NotifyAccessoryAudioLinkClosed() client request for later completion.
         RMessage2 iNotifyAccessoryAudioLinkClosedMsg;
 
         //Thread id of the client-side caller for this subsession
@@ -112,24 +112,24 @@
 
         /**
-        * Handles NotifyAccessoryAudioLinkOpened() client request.
+        * Handles NotifyAccessoryAudioLinkOpenedL() client request.
         * If leave occurs, the client request is completed with that error code.
         *
@@ -112,24 +112,24 @@
 
         /**
-        * Handles NotifyAccessoryAudioLinkClosed() client request.
+        * Handles NotifyAccessoryAudioLinkClosedL() client request.
         * If leave occurs, the client request is completed with that error code.
         *
@@ -182,7 +182,7 @@
 
         /**
-        * Handles NotifyAccessoryAudioLinkOpened() client request.
+        * Handles NotifyAccessoryAudioLinkOpenedL() client request.
         * If leave occurs, the client request is completed with that error code.
         *
@@ -192,7 +192,7 @@
 
         /**
-        * Handles NotifyAccessoryAudioLinkClosed() client request.
+        * Handles NotifyAccessoryAudioLinkClosedL() client request.
         * If leave occurs, the client request is completed with that error code.
         *
@@ -213,10 +213,10 @@
         RMessage2 iAccessoryAudioLinkCloseMsg;
 
-        //Stored NotifyAccessoryAudioLinkOpened() client request for later completion.
+        //Stored NotifyAccessoryAudioLinkOpenedL() client request for later completion.
         RMessage2 iNotifyAccessoryAudioLinkOpenedMsg;
 
@@ -213,10 +213,10 @@
         RMessage2 iNotifyAccessoryAudioLinkOpenedMsg;
 
-        //Stored NotifyAccessoryAudioLinkClosed() client request for later completion.
+        //Stored NotifyAccessoryAudioLinkClosedL() client request for later completion.
         RMessage2 iNotifyAccessoryAudioLinkClosedMsg;
 
--- a/accessoryservices/accessoryserver/src/Server/AccSrvServerModel.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/accessoryservices/accessoryserver/src/Server/AccSrvServerModel.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -717,17 +717,17 @@
     }
 
 // -----------------------------------------------------------------------------
-// CAccSrvServerModel::AddASYThreadId
+// CAccSrvServerModel::AddASYThreadIdL
 // -----------------------------------------------------------------------------
 //
-void CAccSrvServerModel::AddASYThreadId( TUint aThreadID )
+void CAccSrvServerModel::AddASYThreadIdL( TUint aThreadID )
     {
-    COM_TRACE_1( "[AccFW:AccServer] CAccSrvServerModel::AddASYThreadId(%d)", aThreadID );
-    iRegisteredASYs.Append( aThreadID );
+    COM_TRACE_1( "[AccFW:AccServer] CAccSrvServerModel::AddASYThreadIdL(%d)", aThreadID );
+    iRegisteredASYs.AppendL( aThreadID );
     }
 
 // -----------------------------------------------------------------------------
-// CAccSrvServerModel::StoreASYThreadID
+// CAccSrvServerModel::StoreASYThreadIDL
 //
 // If aThreadID can be found from connected ASYs table (iRegisteredASYs),
 // mapping between aUniqueID and aThreadID can be made.
@@ -735,17 +735,17 @@
 // all request for that gineric ID.
 // -----------------------------------------------------------------------------
 //
-void CAccSrvServerModel::StoreASYThreadID( TUint aThreadID, TInt aUniqueID )
+void CAccSrvServerModel::StoreASYThreadIDL( TUint aThreadID, TInt aUniqueID )
     {
-    COM_TRACE_2( "[AccFW:AccServer] CAccSrvServerModel::StoreASYThreadID(%d %d)", aThreadID, aUniqueID );
+    COM_TRACE_2( "[AccFW:AccServer] CAccSrvServerModel::StoreASYThreadIDL(%d %d)", aThreadID, aUniqueID );
     if ( KErrNotFound == iRegisteredASYs.Find( aThreadID ) )
         {
-        COM_TRACE_( "[AccFW:AccServer] CAccSrvServerModel::StoreASYThreadID - Thread ID is not ASYs" );
+        COM_TRACE_( "[AccFW:AccServer] CAccSrvServerModel::StoreASYThreadIDL - Thread ID is not ASYs" );
         }
     else
         {
-        iASYThreadID.Append( aThreadID );
-        iASYUniqueID.Append( aUniqueID );
+        iASYThreadID.AppendL( aThreadID );
+        iASYUniqueID.AppendL( aUniqueID );
         }
     }
 
@@ -758,7 +758,7 @@
     COM_TRACE_1( "[AccFW:AccServer] CAccSrvServerModel::RemoveASYThreadID(%d)", aUniqueID );
     TInt index( iASYUniqueID.Find( aUniqueID ) );
 
     //If index is KErrNotFound, threadIDs are never stored in CAccSrvServerModel::StoreASYThreadID()
     if ( KErrNotFound != index )
         {
         iASYThreadID.Remove( index );
@@ -796,20 +796,20 @@
     }
 
 // -----------------------------------------------------------------------------
-// CAccSrvServerModel::SetMsgThreadIDFilter
+// CAccSrvServerModel::SetMsgThreadIDFilterL
 // -----------------------------------------------------------------------------
 //
-void CAccSrvServerModel::SetMsgThreadIDFilter( TUint aThreadID, TMsgID aMsgID )
+void CAccSrvServerModel::SetMsgThreadIDFilterL( TUint aThreadID, TMsgID aMsgID )
     {
-    COM_TRACE_2( "[AccFW:AccServer] CAccSrvServerModel::SetMsgThreadIDFilter(%d %d)", aThreadID, aMsgID );
+    COM_TRACE_2( "[AccFW:AccServer] CAccSrvServerModel::SetMsgThreadIDFilterL(%d %d)", aThreadID, aMsgID );
 
     TAccSrvThreadIDFilter threadIDFilter;
     threadIDFilter.iThreadID = aThreadID;
     threadIDFilter.iMsgID = aMsgID;
 
-    iThreadIDFilterArray.Append( threadIDFilter );
+    iThreadIDFilterArray.AppendL( threadIDFilter );
 
-    COM_TRACE_1( "[AccFW:AccServer] CAccSrvServerModel::SetMsgThreadIDFilter - count=%d - return void", iThreadIDFilterArray.Count() );
+    COM_TRACE_1( "[AccFW:AccServer] CAccSrvServerModel::SetMsgThreadIDFilterL - count=%d - return void", iThreadIDFilterArray.Count() );
     }
 
 // -----------------------------------------------------------------------------
@@ -861,7 +861,7 @@
     else
         {
         COM_TRACE_1( "[AccFW:AccServer] CAccSrvServerModel::SetCancelledConnectAccessoryL - handling index %d", index );
-        iCancelledConnectAccessory.Append( genericIDArray.GetGenericIDL( index ).UniqueID() );
+        iCancelledConnectAccessory.AppendL( genericIDArray.GetGenericIDL( index ).UniqueID() );
         }
 
     COM_TRACE_( "[AccFW:AccServer] CAccSrvServerModel::SetCancelledConnectAccessoryL - return void" );
@@ -892,7 +892,7 @@
     else
         {
         COM_TRACE_1( "[AccFW:AccServer] CAccSrvServerModel::SetCancelledConnectAccessoryL - handling index %d", index );
-        iCancelledConnectAccessory.Append( genericIDArray.GetGenericIDL( index ).UniqueID() );
+        iCancelledConnectAccessory.AppendL( genericIDArray.GetGenericIDL( index ).UniqueID() );
         }
 
     COM_TRACE_( "[AccFW:AccServer] CAccSrvServerModel::SetCancelledConnectAccessoryL - DeviceAddress - return void" );
@@ -758,7 +758,7 @@
     TInt index( iASYUniqueID.Find( aUniqueID ) );
 
-    //If index is KErrNotFound, threadIDs are never stored in CAccSrvServerModel::StoreASYThreadID()
+    //If index is KErrNotFound, threadIDs are never stored in CAccSrvServerModel::StoreASYThreadIDL()
     if ( KErrNotFound != index )
         {
--- a/accessoryservices/accessoryserver/src/Server/AccSrvSubAudioControl.cpp	Thu Jul 15 20:05:35 2010 +0300
+++ b/accessoryservices/accessoryserver/src/Server/AccSrvSubAudioControl.cpp	Thu Aug 19 11:09:10 2010 +0300
@@ -121,12 +121,12 @@
     }
 
 // -----------------------------------------------------------------------------
-// CAccSrvSubAudioControl::NotifyAccessoryAudioLinkOpened
+// CAccSrvSubAudioControl::NotifyAccessoryAudioLinkOpenedL
 // -----------------------------------------------------------------------------
 //
-void CAccSrvSubAudioControl::NotifyAccessoryAudioLinkOpened( const RMessage2& aMessage )
+void CAccSrvSubAudioControl::NotifyAccessoryAudioLinkOpenedL( const RMessage2& aMessage )
     {
-    COM_TRACE_( "[AccFW:AccServer] CAccSrvSubAudioControl::NotifyAccessoryAudioLinkOpened()" );
+    COM_TRACE_( "[AccFW:AccServer] CAccSrvSubAudioControl::NotifyAccessoryAudioLinkOpenedL()" );
 
     iConnectionController->NotificationQueue().RegisterControlMessage( EAccessoryAudioLinkOpened,
                                                                        this );
@@ -136,24 +136,24 @@
     // If message is null, there is no pending request and no filtering needed
     if ( !iAccessoryAudioLinkOpenMsg.IsNull() )
         {
         //NotifyAccessoryAudioLinkOpened() notification is filtered
         //for AccessoryAudioLinkOpen() caller thread.
         //In this case NotifyAccessoryAudioLinkOpened() notification
         //is ordered after AccessoryAudioLinkOpen() is sent.
-        iConnectionController->ServerModel().SetMsgThreadIDFilter( iCallerThreadID,
+        iConnectionController->ServerModel().SetMsgThreadIDFilterL( iCallerThreadID,
                                                                    EAccessoryAudioLinkOpened );
         }
 
-    COM_TRACE_( "[AccFW:AccServer] CAccSrvSubAudioControl::NotifyAccessoryAudioLinkOpened - return void" );
+    COM_TRACE_( "[AccFW:AccServer] CAccSrvSubAudioControl::NotifyAccessoryAudioLinkOpenedL - return void" );
     }
 
 // -----------------------------------------------------------------------------
-// CAccSrvSubAudioControl::NotifyAccessoryAudioLinkClosed
+// CAccSrvSubAudioControl::NotifyAccessoryAudioLinkClosedL
 // -----------------------------------------------------------------------------
 //
-void CAccSrvSubAudioControl::NotifyAccessoryAudioLinkClosed( const RMessage2& aMessage )
+void CAccSrvSubAudioControl::NotifyAccessoryAudioLinkClosedL( const RMessage2& aMessage )
     {
-    COM_TRACE_( "[AccFW:AccServer] CAccSrvSubAudioControl::NotifyAccessoryAudioLinkClosed()" );
+    COM_TRACE_( "[AccFW:AccServer] CAccSrvSubAudioControl::NotifyAccessoryAudioLinkClosedL()" );
 
     iConnectionController->NotificationQueue().RegisterControlMessage( EAccessoryAudioLinkClosed,
                                                                        this );
@@ -162,15 +162,15 @@
     // If message is null, there is no pending request and no filtering needed
     if ( !iAccessoryAudioLinkCloseMsg.IsNull() )
         {
         //NotifyAccessoryAudioLinkClosed() notification is filtered
         //for AccessoryAudioLinkClose() caller thread.
         //In this case NotifyAccessoryAudioLinkClosed() notification
         //is ordered after AccessoryAudioLinkClose() is sent.
-        iConnectionController->ServerModel().SetMsgThreadIDFilter( iCallerThreadID,
+        iConnectionController->ServerModel().SetMsgThreadIDFilterL( iCallerThreadID,
                                                                    EAccessoryAudioLinkClosed );
         }
 
-    COM_TRACE_( "[AccFW:AccServer] CAccSrvSubAudioControl::NotifyAccessoryAudioLinkClosed - return void" );
+    COM_TRACE_( "[AccFW:AccServer] CAccSrvSubAudioControl::NotifyAccessoryAudioLinkClosedL - return void" );
     }
 
 // -----------------------------------------------------------------------------
@@ -219,9 +219,9 @@
     // If message is null, there is no pending request and no filtering needed
     if ( !iNotifyAccessoryAudioLinkOpenedMsg.IsNull() )
         {
         //NotifyAccessoryAudioLinkOpened notification() is filtered
         //for AccessoryAudioLinkOpen() caller thread
-        iConnectionController->ServerModel().SetMsgThreadIDFilter( iCallerThreadID,
+        iConnectionController->ServerModel().SetMsgThreadIDFilterL( iCallerThreadID,
                                                                    EAccessoryAudioLinkOpened );
         }
 
@@ -263,9 +263,9 @@
     // If message is null, there is no pending request and no filtering needed
     if ( !iNotifyAccessoryAudioLinkClosedMsg.IsNull() )
         {
         //NotifyAccessoryAudioLinkClosed() notification is filtered
         //for AccessoryAudioLinkClose() caller thread
-        iConnectionController->ServerModel().SetMsgThreadIDFilter( 
+        iConnectionController->ServerModel().SetMsgThreadIDFilterL( 
                                                     iCallerThreadID,
                                                     EAccessoryAudioLinkClosed );
         }
@@ -311,7 +311,7 @@
                                                     this );
 
         //AccessoryAudioLinkOpen() request is cancelled
         //-> NO filtering needed for NotifyAccessoryAudioLinkOpened()
         iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter( 
                                                     iCallerThreadID, 
                                                     EAccessoryAudioLinkOpened );
@@ -340,7 +340,7 @@
                                                                          this );
 
         //AccessoryAudioLinkClose() request is cancelled
         //-> NO filtering needed for NotifyAccessoryAudioLinkClosed()
         iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
             iCallerThreadID, EAccessoryAudioLinkClosed );
 
@@ -367,7 +367,7 @@
         iConnectionController->NotificationQueue().CancelControlMessage( 
             EAccessoryAudioLinkOpened, this );
 
         //NotifyAccessoryAudioLinkOpened() notification order is cancelled
         //-> NO filtering needed for that message
         iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter( 
             iCallerThreadID, EAccessoryAudioLinkOpened );
@@ -394,7 +394,7 @@
         iConnectionController->NotificationQueue().CancelControlMessage( 
             EAccessoryAudioLinkClosed, this );
 
         //NotifyAccessoryAudioLinkClosed() notification order is cancelled
         //-> NO filtering needed for that message
         iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
             iCallerThreadID, EAccessoryAudioLinkClosed );
@@ -422,12 +422,12 @@
         {
         case EAccSrvNotifyAccessoryAudioLinkOpened:
             {
-            NotifyAccessoryAudioLinkOpened( aMessage );
+            NotifyAccessoryAudioLinkOpenedL( aMessage );
             break;
             }
         case EAccSrvNotifyAccessoryAudioLinkClosed:
             {
-            NotifyAccessoryAudioLinkClosed( aMessage );
+            NotifyAccessoryAudioLinkClosedL( aMessage );
             break;
             }
         case EAccSrvAccessoryAudioLinkOpen:
@@ -494,7 +494,7 @@
             {
             if( KErrNone != aErrorCode )
                 {
                 //Release NotifyAccessoryAudioLinkOpened() filtering in error case.
                 //BluetoothAudioLinkOpenedNotify() message is never sent in error case
                 iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
                                                                     iCallerThreadID,
@@ -511,7 +511,7 @@
             {
             if( KErrNone != aErrorCode )
                 {
                 //Release NotifyAccessoryAudioLinkClosed() filtering in error case.
                 //BluetoothAudioLinkClosedNotify() message is never sent in error case
                 iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
                                                                     iCallerThreadID,
@@ -526,13 +526,13 @@
 
         case EAccessoryAudioLinkOpened:
             {
             // Nothing is done here if filter is set, i.e. NotifyAccessoryAudioLinkOpened()
             // notification was ordered from the same thread that AccessoryAudioLinkOpen() was called
             if ( !iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter( 
                                                                     iCallerThreadID, 
                                                                     EAccessoryAudioLinkOpened ) )
                 {
                 //Complete outstanding NotifyAccessoryAudioLinkOpened request
                 //Notice, This works for single client (Server model can store only one value)
                 TAccAudioType    audioType( iConnectionController->ServerModel().AudioType() );
                 TAccPolGenericID genericID;
@@ -555,13 +555,13 @@
 
         case EAccessoryAudioLinkClosed:
             {
             // Nothing is done here if filter is set, i.e. NotifyAccessoryAudioLinkClosed() 
             // notification was ordered from the same thread that AccessoryAudioLinkClose() was called
             if ( !iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
                                                                     iCallerThreadID,
                                                                     EAccessoryAudioLinkClosed ) )
                 {
                 //Complete outstanding NotifyAccessoryAudioLinkClosed request
                 //Notice, This works for single client (Server model can store only one value)
                 TAccAudioType    audioType( iConnectionController->ServerModel().AudioType() );
                 TAccPolGenericID genericID;
@@ -136,24 +136,24 @@
     if ( !iAccessoryAudioLinkOpenMsg.IsNull() )
         {
-        //NotifyAccessoryAudioLinkOpened() notification is filtered
+        //NotifyAccessoryAudioLinkOpenedL() notification is filtered
         //for AccessoryAudioLinkOpen() caller thread.
@@ -136,24 +136,24 @@
         //for AccessoryAudioLinkOpen() caller thread.
-        //In this case NotifyAccessoryAudioLinkOpened() notification
+        //In this case NotifyAccessoryAudioLinkOpenedL() notification
         //is ordered after AccessoryAudioLinkOpen() is sent.
@@ -162,15 +162,15 @@
     if ( !iAccessoryAudioLinkCloseMsg.IsNull() )
         {
-        //NotifyAccessoryAudioLinkClosed() notification is filtered
+        //NotifyAccessoryAudioLinkClosedL() notification is filtered
         //for AccessoryAudioLinkClose() caller thread.
@@ -162,15 +162,15 @@
         //for AccessoryAudioLinkClose() caller thread.
-        //In this case NotifyAccessoryAudioLinkClosed() notification
+        //In this case NotifyAccessoryAudioLinkClosedL() notification
         //is ordered after AccessoryAudioLinkClose() is sent.
@@ -219,9 +219,9 @@
     if ( !iNotifyAccessoryAudioLinkOpenedMsg.IsNull() )
         {
-        //NotifyAccessoryAudioLinkOpened notification() is filtered
+        //NotifyAccessoryAudioLinkOpenedL notification() is filtered
         //for AccessoryAudioLinkOpen() caller thread
@@ -263,9 +263,9 @@
     if ( !iNotifyAccessoryAudioLinkClosedMsg.IsNull() )
         {
-        //NotifyAccessoryAudioLinkClosed() notification is filtered
+        //NotifyAccessoryAudioLinkClosedL() notification is filtered
         //for AccessoryAudioLinkClose() caller thread
@@ -311,7 +311,7 @@
 
         //AccessoryAudioLinkOpen() request is cancelled
-        //-> NO filtering needed for NotifyAccessoryAudioLinkOpened()
+        //-> NO filtering needed for NotifyAccessoryAudioLinkOpenedL()
         iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter( 
                                                     iCallerThreadID, 
@@ -340,7 +340,7 @@
 
         //AccessoryAudioLinkClose() request is cancelled
-        //-> NO filtering needed for NotifyAccessoryAudioLinkClosed()
+        //-> NO filtering needed for NotifyAccessoryAudioLinkClosedL()
         iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
             iCallerThreadID, EAccessoryAudioLinkClosed );
@@ -367,7 +367,7 @@
             EAccessoryAudioLinkOpened, this );
 
-        //NotifyAccessoryAudioLinkOpened() notification order is cancelled
+        //NotifyAccessoryAudioLinkOpenedL() notification order is cancelled
         //-> NO filtering needed for that message
         iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter( 
@@ -394,7 +394,7 @@
             EAccessoryAudioLinkClosed, this );
 
-        //NotifyAccessoryAudioLinkClosed() notification order is cancelled
+        //NotifyAccessoryAudioLinkClosedL() notification order is cancelled
         //-> NO filtering needed for that message
         iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
@@ -494,7 +494,7 @@
             if( KErrNone != aErrorCode )
                 {
-                //Release NotifyAccessoryAudioLinkOpened() filtering in error case.
+                //Release NotifyAccessoryAudioLinkOpenedL() filtering in error case.
                 //BluetoothAudioLinkOpenedNotify() message is never sent in error case
                 iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
@@ -511,7 +511,7 @@
             if( KErrNone != aErrorCode )
                 {
-                //Release NotifyAccessoryAudioLinkClosed() filtering in error case.
+                //Release NotifyAccessoryAudioLinkClosedL() filtering in error case.
                 //BluetoothAudioLinkClosedNotify() message is never sent in error case
                 iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
@@ -526,13 +526,13 @@
         case EAccessoryAudioLinkOpened:
             {
-            // Nothing is done here if filter is set, i.e. NotifyAccessoryAudioLinkOpened()
+            // Nothing is done here if filter is set, i.e. NotifyAccessoryAudioLinkOpenedL()
             // notification was ordered from the same thread that AccessoryAudioLinkOpen() was called
             if ( !iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter( 
@@ -526,13 +526,13 @@
                                                                     EAccessoryAudioLinkOpened ) )
                 {
-                //Complete outstanding NotifyAccessoryAudioLinkOpened request
+                //Complete outstanding NotifyAccessoryAudioLinkOpenedL request
                 //Notice, This works for single client (Server model can store only one value)
                 TAccAudioType    audioType( iConnectionController->ServerModel().AudioType() );
@@ -555,13 +555,13 @@
         case EAccessoryAudioLinkClosed:
             {
-            // Nothing is done here if filter is set, i.e. NotifyAccessoryAudioLinkClosed() 
+            // Nothing is done here if filter is set, i.e. NotifyAccessoryAudioLinkClosedL() 
             // notification was ordered from the same thread that AccessoryAudioLinkClose() was called
             if ( !iConnectionController->ServerModel().FindAndDeleteMsgThreadIDFilter(
@@ -555,13 +555,13 @@
                                                                     EAccessoryAudioLinkClosed ) )
                 {
-                //Complete outstanding NotifyAccessoryAudioLinkClosed request
+                //Complete outstanding NotifyAccessoryAudioLinkClosedL request
                 //Notice, This works for single client (Server model can store only one value)
                 TAccAudioType    audioType( iConnectionController->ServerModel().AudioType() );